/**
 *@des 商品模块接口
 *@author zhengjinyi
 *@date 2020/03/19 14:56:57
 *@param registerByPass
 */
import request from '@/common/config/caimeiApi.js'
import $reg from '@/common/config/common.js'

/**
 * 获取分类导航
 */
export function queryGoodscategory() {
	return new Promise(function(resolve,reject) {
		request.get("/product/classify",{}, res => {
			if(res.code == 0){
				resolve(res);
			}else{
				reject(res)
			}
		})
	});
}
/**
 * @三级分类下的商品列表
 * @param:tinyTypeID 三级分类ID
 * @param:pageNum	页码
 * @param:pageSize	每页显示条数
 */
export function queryGoodslist(url,params) {
	return new Promise(function(resolve,reject) {
		request.lodingGet(url,params, res => {
			if(res.code == 0){
				resolve(res);
			}else{
				reject(res)
			}
		})
	});
}
/**
 * @新分类下的商品列表
 * @param:tinyTypeID 三级分类ID
 * @param:pageNum	页码
 * @param:pageSize	每页显示条数
 */
export function searchQueryTinyType(url,params) {
	return new Promise(function(resolve,reject) {
		request.lodingGet(url,params, res => {
			if(res.code == 0){
				resolve(res);
			}else{
				reject(res)
			}
		})
	});
}
/**
 * @商品搜索
 * @param:userId 用户ID
 * @param:searchWord 关键词
 * @param:pageNum	页码
 * @param:pageSize	每页显示条数
 */
export function querySearchProduct(params) {
	return new Promise(function(resolve,reject) {
		request.lodingGet("/product/search",params, res => {
			if(res.code == 0){
				resolve(res);
			}else{
				reject(res)
			}
		})
	});
}
/**
 * @新商品搜索
 * @param:keyword 关键词
 * @param:pageNum	页码
 * @param:pageSize	每页显示条数
 * @param:sortField	价格排序
 * @param:sortType	类型排序
 */
export function queryNewSearchProduct(params) {
	return new Promise(function(resolve,reject) {
		request.lodingGet("/search/query/product",params, res => {
			if(res.code == 0){
				resolve(res);
			}else{
				reject(res)
			}
		})
	});
}
/**
 * @新商品搜索重新请求价格
 * @param:productIds 商品ID
 * @param:userId	用户ID
 */
export function querySearchProductPrice(params) {
	return new Promise(function(resolve,reject) {
		request.get("/product/listPrice",params, res => {
			if(res.code == 0){
				resolve(res);
			}else{
				reject(res)
			}
		})
	});
}
/**
 * @新商品搜索查询商品阶梯价格
 * @param:productIds 商品ID
 * @param:userId	用户ID
 */
export function querySearchProductLadderPrice(params) {
	return new Promise(function(resolve,reject) {
		request.get("/product/ladderPrice",params, res => {
			if(res.code == 0){
				resolve(res);
			}else{
				reject(res)
			}
		})
	});
}
/**
 * @搜索历史记录
 * @param:userId 用户ID
 */
export function querySearchHistory(params) {
	return new Promise(function(resolve,reject) {
		request.get("/product/searchHistory",params, res => {
			resolve(res);
		})
	});
}
/**
 * @添加搜索历史记录
 * @param:userId 用户ID
 * @param:keyword 用户ID
 */
export function searchHistoryAdd(params) {
	return new Promise(function(resolve,reject) {
		request.get("/product/history/add",params, res => {
			resolve(res);
		})
	});
}

/**
 * @清除历史记录
 * @param:userId 用户ID
 */
export function clearSearchHistory(params) {
	return new Promise(function(resolve,reject) {
		request.lodingGet("/product/searchHistory/delete",params, res => {
			if(res.code == 0){
				resolve(res);
			}else{
				reject(res)
			}
		})
	});
}
/**
 * @商品详情
 * @param:productID 商品ID
 */
export function queryProductDetils(params) {
	return new Promise(function(resolve,reject) {
		request.get("/product/details",params, res => {
			if(res.code == 0){
				resolve(res);
			}else{
				reject(res)
			}
		})
	});
}
/**
 * @商品相关推荐
 * @param:productID 商品ID
 */
export function queryRelevant(params) {
	return new Promise(function(resolve,reject) {
		request.get("/product/relevant",params, res => {
			if(res.code == 0){
				resolve(res);
			}else{
				reject(res)
			}
		})
	});
}
/**
 * @商品评价
 * @param:productID 商品ID
 */
export function queryEvaluate(params) {
	return new Promise(function(resolve,reject) {
		request.get("/product/evaluate",params, res => {
			if(res.code == 0){
				resolve(res);
			}else{
				reject(res)
			}
		})
	});
}
/**
 * @常用商品，精品推荐，热门推荐列表
 * @param:preferredFlag 新品上线(001) 优惠商品(010) 常用商品(100)，，
 * @param:pageNum 页码
 * @param:pageSize 每页条数
 */
export function queryPreferred(params) {
	return new Promise(function(resolve,reject) {
		request.get("/product/preferred",params, res => {
			if(res.code == 0){
				resolve(res);
			}else{
				reject(res)
			}
		})
	});
}
/**
 * @再次购买商品列表
 * @param:userId  用户ID
 * @param:pageNum 页码
 * @param:pageSize 每页条数
 */
export function queryAgaingoodslist(params) {
	return new Promise(function(resolve,reject) {
		request.lodingGet("/repeat/buyAgain",params, res => {
			if(res.code == 0){
				resolve(res);
			}else{
				reject(res)
			}
		})
	});
}
/**
 * @加入购物车
 * @param:
 * @param:pageNum 页码
 * @param:pageSize 每页条数
 */
export function addCart(params) {
	return new Promise(function(resolve,reject) {
		request.get("/product//preferred",params, res => {
			if(res.code == 0){
				resolve(res);
			}else{
				reject(res)
			}
		})
	});
}

